@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate test stubs for methods
 
-our $VERSION = '0.0200';
+our $VERSION = '0.0201';
 
 use Moo;
 use strictures 2;
@@ -68,7 +68,7 @@ sub create_test {
 
     open my $fh, '>', $self->name or die "Can't write " . $self->name . ": $!";
 
-    my $text =<<"END";
+    my $text =<<'END';
 use strict;
 use warnings;
 
@@ -90,6 +90,9 @@ END
         $text .= "$test\n\n";
     }
 
+    $text .= 'done_testing();
+';
+
     print $fh $text;
 }
 
@@ -107,7 +110,7 @@ Test::NaiveStubs - Generate test stubs for methods
 
 =head1 VERSION
 
-version 0.0200
+version 0.0201
 
 =head1 SYNOPSIS
 
@@ -120,7 +123,7 @@ version 0.0200
 
 =head1 DESCRIPTION
 
-A C<Test::NaiveStubs> generates a test file of stubs for exercising all the
+C<Test::NaiveStubs> generates a test file of stubs for exercising all the
 methods (not functions) of a given B<class>.
 
 For a more powerful alternative, check out L<Test::StubGenerator>.
@@ -174,7 +177,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Gene Boggs.
+This software is copyright (c) 2019 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
